PyChart
=======

Libreria python per generare semplici grafici tramite la libreria Pillow.

Versione 1.1.0

Installazione
-------------

pip install PyChart-busnellistefano -U

Utilizzo
--------

$ python

from pychart import *
from pychart import Mapper
from pychart import Graph
from pychart import Panel 
from pychart import Chart

Classi
------

* Mapper

* Graph

* Panel

* Chart
